package eu.greenlightning.gdx.labyrinthchallenge;

import com.badlogic.gdx.*;
import com.badlogic.gdx.Graphics.DisplayMode;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.GL20;

import eu.greenlightning.gdx.labyrinthchallenge.screens.*;
import eu.greenlightning.gdx.labyrinthchallenge.util.*;

public class LabyrinthGame extends Game {

	private final ScreenshotFactory factory;

	private int windowWidth;
	private int windowHeight;

	private Background background;
	private Sounds sounds;
	private Stats stats;

	private MenuScreen menu;
	private PlayScreen play;
	private WinScreen win;

	public LabyrinthGame() {
		this(new NoScreenshotFactory());
	}

	public LabyrinthGame(ScreenshotFactory factory) {
		this.factory = factory;
	}

	@Override
	public void create() {
		background = new Background();
		sounds = new Sounds();
		stats = new Stats();
		menu = new MenuScreen(this);
		play = new PlayScreen(this);
		win = new WinScreen(this);
		setScreen(menu);
	}

	public Sounds getSounds() {
		return sounds;
	}

	public Stats getStats() {
		return stats;
	}

	public MenuScreen getMenuScreen() {
		return menu;
	}

	public PlayScreen getPlayScreen() {
		return play;
	}

	public WinScreen getWinScreen() {
		return win;
	}

	@Override
	public void resize(int width, int height) {
		background.resize(width, height);
		super.resize(width, height);
	}

	@Override
	public void render() {
		clear();
		background.render();
		super.render();
		checkScreenshot();
		checkFullscreen();
	}

	private void clear() {
		Gdx.gl.glClearColor(0, 0, 0, 1);
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);
	}

	private void checkScreenshot() {
		if (Gdx.input.isKeyJustPressed(Input.Keys.F2)) {
			factory.saveScreenshot();
		}
	}

	private void checkFullscreen() {
		if (Gdx.input.isKeyJustPressed(Keys.F11) && Gdx.graphics.supportsDisplayModeChange()) {
			toggleFullscreen();
		}
	}

	private void toggleFullscreen() {
		if (Gdx.graphics.isFullscreen()) {
			Gdx.graphics.setDisplayMode(windowWidth, windowHeight, false);
		} else {
			windowWidth = Gdx.graphics.getWidth();
			windowHeight = Gdx.graphics.getHeight();
			DisplayMode displayMode = Gdx.graphics.getDesktopDisplayMode();
			Gdx.graphics.setDisplayMode(displayMode.width, displayMode.height, true);
		}
	}

	@Override
	public void dispose() {
		super.dispose();
		win.dispose();
		play.dispose();
		menu.dispose();
		sounds.dispose();
		background.dispose();
	}

}
