package eu.greenlightning.gdx.labyrinthchallenge.items;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.audio.Sound;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Batch;
import com.badlogic.gdx.graphics.g2d.Sprite;

import eu.greenlightning.gdx.labyrinthchallenge.labyrinth.Labyrinth;
import eu.greenlightning.gdx.labyrinthchallenge.labyrinth.Material;

public class Teleporter implements Item {

	private Sprite sprite;
	private Sound sound;
	private boolean up;

	public Teleporter(boolean up, int rotation) {
		this.sprite = new Sprite(new Texture("graphics/teleporter-" + (up ? "up" : "down") + ".png"));
		sprite.setRotation(rotation * 90);
		this.sound = Gdx.audio.newSound(Gdx.files.internal("sounds/teleporter-" + (up ? "up" : "down")
			+ ".wav"));
		this.up = up;
	}

	public boolean isUp() {
		return up;
	}

	@Override
	public void interact(Labyrinth labyrinth) {
		sound.play();
		if (up) {
			labyrinth.goUp();
		} else {
			labyrinth.goDown();
		}
	}

	@Override
	public void draw(Batch batch, int x, int y) {
		sprite.setX(x * Material.SIZE);
		sprite.setY(y * Material.SIZE);
		sprite.draw(batch);
	}

	@Override
	public void dispose() {
		sound.dispose();
		sprite.getTexture().dispose();
	}

}
