package eu.greenlightning.gdx.labyrinthchallenge.labyrinth;

import com.badlogic.gdx.math.MathUtils;

import eu.greenlightning.gdx.labyrinthchallenge.items.Teleporter;

public class LabyrinthGenerator {

	private Labyrinth labyrinth;
	private boolean[][][] visited;
	private int playerX;
	private int playerY;

	public LabyrinthGenerator(int difficulty) {
		labyrinth = new Labyrinth(difficulty);
		visited = new boolean[labyrinth.getSize()][labyrinth.getSize()][labyrinth.getHeight()];
		playerX = MathUtils.random(0, labyrinth.getSize() - 1);
		playerY = MathUtils.random(0, labyrinth.getSize() - 1);
		int sizeSquared = labyrinth.getSize() * labyrinth.getSize();
		int length = MathUtils.random(sizeSquared / 4, sizeSquared / 2);
		int level = MathUtils.random(0, labyrinth.getHeight() - 1);
		new Runner(this, true, length, new Position(playerX, playerY, level));
		clearUselessStairs();
		labyrinth.setLevel(level);
	}

	private void clearUselessStairs() {
		for (int x = 0; x < labyrinth.getSize(); x++) {
			for (int y = 0; y < labyrinth.getSize(); y++) {
				for (int z = 0; z < labyrinth.getHeight(); z++) {
					if (hasTeleporter(x, y, z) && isClosed(x, y, z)) {
						clearTeleporter(x, y, z);
						clear(x, y, z);
					}
				}
			}
		}
	}

	public boolean hasTeleporter(int x, int y, int z) {
		return labyrinth.hasItem(x, y, z) && labyrinth.getItem(x, y, z) instanceof Teleporter;
	}

	public boolean isClosed(int x, int y, int z) {
		return !labyrinth.isTopClear(x, y, z) && !labyrinth.isBottomClear(x, y, z)
			&& !labyrinth.isLeftClear(x, y, z) && !labyrinth.isRightClear(x, y, z);
	}

	public void clearTeleporter(int x, int y, int z) {
		Teleporter teleporter = (Teleporter) labyrinth.getItem(x, y, z);
		if (teleporter.isUp()) {
			labyrinth.clearItem(x, y, z - 1);
		} else {
			labyrinth.clearItem(x, y, z + 1);
		}
		labyrinth.clearItem(x, y, z);
	}

	public void clear(int x, int y, int z) {
		if (MathUtils.randomBoolean()) {
			clearHorizontally(x, y, z);
		} else {
			clearVertically(x, y, z);
		}
	}

	public void clearHorizontally(int x, int y, int z) {
		if (x == 0) {
			labyrinth.clearRight(x, y, z);
		} else if (x == labyrinth.getSize() - 1) {
			labyrinth.clearLeft(x, y, z);
		} else {
			if (MathUtils.randomBoolean()) {
				labyrinth.clearRight(x, y, z);
			} else {
				labyrinth.clearLeft(x, y, z);
			}
		}
	}

	public void clearVertically(int x, int y, int z) {
		if (y == 0) {
			labyrinth.clearTop(x, y, z);
		} else if (y == labyrinth.getSize() - 1) {
			labyrinth.clearBottom(x, y, z);
		} else {
			if (MathUtils.randomBoolean()) {
				labyrinth.clearTop(x, y, z);
			} else {
				labyrinth.clearBottom(x, y, z);
			}
		}
	}
	public Labyrinth getLabyrinth() {
		return labyrinth;
	}

	public int getPlayerX() {
		return playerX;
	}

	public int getPlayerY() {
		return playerY;
	}

	public void visit(Position position) {
		visited[position.getX()][position.getY()][position.getZ()] = true;
	}

	public boolean isVisited(Position position) {
		return visited[position.getX()][position.getY()][position.getZ()];
	}

}
