package eu.greenlightning.gdx.labyrinthchallenge.labyrinth;

import com.badlogic.gdx.graphics.*;
import com.badlogic.gdx.graphics.Pixmap.Format;
import com.badlogic.gdx.graphics.g2d.Batch;

public enum Material {

	EMPTY, GRASS("grass.png"), DIRT("dirt.png"), STONE("stone.png");

	public static final int SIZE = 32;

	private Texture tile;
	private Texture wall;

	private Material() {
		Pixmap pixmap = new Pixmap(0, 0, Format.RGBA8888);
		tile = new Texture(pixmap);
		wall = new Texture(pixmap);
	}

	private Material(String path) {
		tile = new Texture("graphics/tiles/" + path);
		wall = new Texture("graphics/walls/" + path);
	}

	public void drawTile(Batch batch, float x, float y) {
		batch.draw(tile, x, y);
	}

	public void drawHorizontalWall(Batch batch, float x, float y) {
		float offset = wall.getWidth() / 2f;
		batch.draw(wall, x - offset, y - offset, offset, offset, wall.getWidth(), wall.getHeight(), 1, 1,
			270, 0, 0, wall.getWidth(), wall.getHeight(), false, false);
	}

	public void drawVerticalWall(Batch batch, float x, float y) {
		batch.draw(wall, x - wall.getWidth() / 2f, y - wall.getWidth() / 2f);
	}

	public static void dipose() {
		for (Material tile : values()) {
			tile.dispose();
		}
	}

	public void dispose() {
		wall.dispose();
		tile.dispose();
	}

}
