package eu.greenlightning.gdx.labyrinthchallenge.player;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.math.Interpolation;

public class Interpolator<V extends Number> {

	private V old;
	private V current;
	private float time;
	private float total;
	private Interpolation interpolation;
	private float value;

	public Interpolator(V start, float total, Interpolation interpolation) {
		this.old = start;
		this.current = start;
		this.time = 0;
		this.total = total;
		this.interpolation = interpolation;
		this.value = start.floatValue();
	}

	public V getOld() {
		return old;
	}

	public V getCurrent() {
		return current;
	}

	public float getValue() {
		return value;
	}

	public void interpolate(V next) {
		interpolate(current, next);
	}

	public void interpolate(V from, V to) {
		old = from;
		current = to;
		time = 0;
		value = from.floatValue();
	}

	public void update() {
		update(Gdx.graphics.getDeltaTime());
	}

	public void update(float delta) {
		time += delta;
		if (isChanging()) {
			value = interpolation.apply(old.floatValue(), current.floatValue(), time / total);
		} else {
			value = current.floatValue();
		}
	}

	public boolean isChanging() {
		return time < total;
	}

}
