package eu.greenlightning.gdx.labyrinthchallenge.screens;

import com.badlogic.gdx.*;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Batch;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.utils.viewport.FitViewport;
import com.badlogic.gdx.utils.viewport.Viewport;

import eu.greenlightning.gdx.labyrinthchallenge.LabyrinthGame;
import eu.greenlightning.gdx.labyrinthchallenge.util.Overlay;

public class MenuScreen extends ScreenAdapter {

	private LabyrinthGame game;
	private Batch batch;
	private Texture menu;
	private Viewport viewport;
	private Overlay overlay;

	public MenuScreen(LabyrinthGame game) {
		this.game = game;
		batch = new SpriteBatch();
		menu = new Texture("interface/menu.png");
		viewport = new FitViewport(menu.getWidth(), menu.getHeight());
		overlay = new Overlay();
	}

	@Override
	public void resize(int width, int height) {
		viewport.update(width, height, true);
	}

	@Override
	public void show() {
		overlay.show();
	}

	@Override
	public void render(float delta) {
		if (Gdx.input.isKeyJustPressed(Keys.SPACE)) {
			game.getStats().reset();
			game.setScreen(game.getPlayScreen());
			game.getSounds().start();
		}
		overlay.update(delta);
		viewport.apply();
		batch.setProjectionMatrix(viewport.getCamera().projection);
		batch.setTransformMatrix(viewport.getCamera().view);
		batch.begin();
		batch.draw(menu, 0, 0);
		overlay.draw(batch);
		batch.end();
	}

	@Override
	public void dispose() {
		overlay.dispose();
		menu.dispose();
		batch.dispose();
	}

}
