package eu.greenlightning.gdx.labyrinthchallenge.screens;

import com.badlogic.gdx.*;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.Camera;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.Batch;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.utils.viewport.FillViewport;
import com.badlogic.gdx.utils.viewport.Viewport;

import eu.greenlightning.gdx.labyrinthchallenge.LabyrinthGame;
import eu.greenlightning.gdx.labyrinthchallenge.items.Treasure;
import eu.greenlightning.gdx.labyrinthchallenge.labyrinth.*;
import eu.greenlightning.gdx.labyrinthchallenge.player.Player;
import eu.greenlightning.gdx.labyrinthchallenge.util.Stats;

public class PlayScreen extends ScreenAdapter {

	private LabyrinthGame game;
	private Stats stats;
	private Batch batch;
	private Camera camera;
	private Viewport viewport;
	private Labyrinth labyrinth;
	private Player player;

	public PlayScreen(LabyrinthGame game) {
		this.game = game;
		stats = game.getStats();
		batch = new SpriteBatch();
		camera = new OrthographicCamera();
		viewport = new FillViewport(5 * Material.SIZE, 5 * Material.SIZE, camera);
	}

	@Override
	public void resize(int width, int height) {
		viewport.update(width, height, false);
	}

	@Override
	public void show() {
		stats.startLevel();
		LabyrinthGenerator generator = new LabyrinthGenerator(stats.getDifficulty());
		labyrinth = generator.getLabyrinth();
		player = new Player(labyrinth, generator.getPlayerX(), generator.getPlayerY());
	}

	@Override
	public void render(float delta) {
		stats.addTime(delta);
		labyrinth.update();
		player.update();
		camera.position.set(player.getCenterX(), player.getCenterY(), 0);
		viewport.apply();
		batch.setProjectionMatrix(camera.projection);
		batch.setTransformMatrix(camera.view);
		batch.begin();
		labyrinth.draw(batch);
		player.draw(batch);
		batch.end();
		if (labyrinth.hasItem(player.getStadingOnX(), player.getStandingOnY())
			&& labyrinth.getItem(player.getStadingOnX(), player.getStandingOnY()) instanceof Treasure) {
			game.setScreen(game.getWinScreen());
			game.getSounds().win();
		}
		if (Gdx.input.isKeyJustPressed(Keys.ESCAPE)) {
			game.setScreen(game.getMenuScreen());
			game.getSounds().end();
		}
	}
	@Override
	public void hide() {
		player.dispose();
		labyrinth.dispose();
	}

	@Override
	public void dispose() {
		batch.dispose();
		Material.dipose();
	}

}
