package eu.greenlightning.gdx.labyrinthchallenge.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.ScreenAdapter;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.*;
import com.badlogic.gdx.utils.viewport.FitViewport;
import com.badlogic.gdx.utils.viewport.Viewport;

import eu.greenlightning.gdx.labyrinthchallenge.LabyrinthGame;
import eu.greenlightning.gdx.labyrinthchallenge.util.Overlay;
import eu.greenlightning.gdx.labyrinthchallenge.util.Stats;

public class WinScreen extends ScreenAdapter {

	private LabyrinthGame game;
	private Stats stats;
	private Batch batch;
	private Texture win;
	private Viewport viewport;
	private Texture easy;
	private Texture medium;
	private Texture hard;
	private Texture brutal;
	private BitmapFont font;
	private Overlay overlay;

	public WinScreen(LabyrinthGame game) {
		this.game = game;
		stats = game.getStats();
		batch = new SpriteBatch();
		win = new Texture("interface/win.png");
		viewport = new FitViewport(win.getWidth(), win.getHeight());
		easy = new Texture("interface/difficulty/easy.png");
		medium = new Texture("interface/difficulty/medium.png");
		hard = new Texture("interface/difficulty/hard.png");
		brutal = new Texture("interface/difficulty/brutal.png");
		font = new BitmapFont(Gdx.files.internal("interface/font.fnt"));
		overlay = new Overlay();
	}

	@Override
	public void resize(int width, int height) {
		viewport.update(width, height, true);
	}

	@Override
	public void show() {
		overlay.show();
	}

	@Override
	public void render(float delta) {
		if (Gdx.input.isKeyJustPressed(Keys.SPACE)) {
			game.setScreen(game.getPlayScreen());
			game.getSounds().start();
		} else if (Gdx.input.isKeyJustPressed(Keys.ESCAPE)) {
			game.setScreen(game.getMenuScreen());
			game.getSounds().end();
		}
		overlay.update(delta);
		viewport.apply();
		batch.setProjectionMatrix(viewport.getCamera().projection);
		batch.setTransformMatrix(viewport.getCamera().view);
		batch.begin();
		batch.draw(win, 0, 0);
		drawDifficulty();
		font.draw(batch, formatTime(stats.getLevelTime()), 66, 56);
		font.draw(batch, formatTime(stats.getTotalTime()), 66, 46);
		overlay.draw(batch);
		batch.end();
	}

	public void drawDifficulty() {
		switch (stats.getDifficulty()) {
			case 1:
				batch.draw(easy, 65, 57);
				break;
			case 2:
				batch.draw(medium, 65, 57);
				break;
			case 3:
				batch.draw(hard, 65, 57);
				break;
			default:
				batch.draw(brutal, 65, 57);
				font.draw(batch, "(" + String.valueOf(stats.getDifficulty() - 3) + ")", 67 + brutal
					.getWidth(), 66);
				break;
		}
	}

	private String formatTime(float time) {
		int hours = (int) (time / (60 * 60));
		time -= hours * 60 * 60;
		int minutes = (int) (time / 60);
		time -= minutes * 60;
		int seconds = (int) time;
		time -= seconds;
		int millis = (int) (time * 1000);
		return pad(hours, 2) + ":" + pad(minutes, 2) + ":" + pad(seconds, 2) + "." + pad(millis, 3);
	}

	private String pad(int value, int length) {
		return pad(String.valueOf(value), length);
	}

	private String pad(String value, int length) {
		while (value.length() < length) {
			value = "0" + value;
		}
		return value;
	}

	@Override
	public void dispose() {
		overlay.dispose();
		win.dispose();
		batch.dispose();
	}

}
