package eu.greenlightning.gdx.labyrinthchallenge;

import java.nio.ByteBuffer;
import java.text.SimpleDateFormat;
import java.util.Date;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.graphics.Pixmap;
import com.badlogic.gdx.graphics.PixmapIO;
import com.badlogic.gdx.utils.ScreenUtils;

import eu.greenlightning.gdx.labyrinthchallenge.util.ScreenshotFactory;

public class DesktopScreenshotFactory implements ScreenshotFactory {

	private SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd_HH.mm.ss");

	@Override
	public void saveScreenshot() {
		saveScreenshot(0, 0, Gdx.graphics.getWidth(), Gdx.graphics.getHeight());
	}

	@Override
	public void saveScreenshot(int x, int y, int w, int h) {
		try {
			trySaveScreenshot(x, y, w, h);
		} catch (Exception e) {}
	}

	public void trySaveScreenshot(int x, int y, int w, int h) {
		String text = format.format(new Date());
		FileHandle fileHandle = new FileHandle("screenshots/screenshot_" + text + ".png");
		int count = 0;
		while (fileHandle.exists()) {
			fileHandle = new FileHandle("screenshots/screenshot_" + text + "_" + (count++) + ".png");
		}
		Pixmap pixmap = ScreenUtils.getFrameBufferPixmap(x, y, w, h);
		flip(pixmap);
		PixmapIO.writePNG(fileHandle, pixmap);
		pixmap.dispose();
	}

	private void flip(Pixmap pixmap) {
		int width = pixmap.getWidth();
		int height = pixmap.getHeight();
		ByteBuffer pixels = pixmap.getPixels();
		byte[] bytes = new byte[width * height * 4];
		int lineLength = width * 4;
		for (int line = 0; line < height; line++) {
			pixels.position((height - line - 1) * lineLength);
			pixels.get(bytes, line * lineLength, lineLength);
		}
		pixels.clear();
		pixels.put(bytes);
	}

}